@@ -8,19 +8,19 @@ from yandex.cloud.access.access_pb2 import (
     AccessBinding,
     ListAccessBindingsRequest,
     SetAccessBindingsMetadata, SetAccessBindingsRequest, Subject,
-)
+    )
 from yandex.cloud.serverless.functions.v1.function_pb2 import (
     Function,
     Package,
     Resources,
     Version,
-)
+    )
 from yandex.cloud.serverless.functions.v1.function_service_pb2 import (
     CreateFunctionMetadata, CreateFunctionRequest,
     CreateFunctionVersionMetadata, CreateFunctionVersionRequest,
     DeleteFunctionMetadata, DeleteFunctionRequest,
     GetFunctionVersionByTagRequest, ListFunctionsRequest,
-)
+    )
 from yandex.cloud.serverless.functions.v1.function_service_pb2_grpc import \
     FunctionServiceStub
 
@@ -62,12 +62,12 @@ class YcFunctionsMixin:
                 folder_id=self.folder_id,
                 name=name,
                 description=description,
-            ))
+                ))
         operation_result = self.sdk.wait_operation_and_get_result(
             operation,
             response_type=Function,
             meta_type=CreateFunctionMetadata,
-        )
+            )
         function = operation_result.response
         self.set_function_access(function.id, is_public)
         return function, True
@@ -77,12 +77,12 @@ class YcFunctionsMixin:
         operation = self.sdk.client(FunctionServiceStub).Delete(
             DeleteFunctionRequest(
                 function_id=function.id
-            ))
+                ))
         operation_result = self.sdk.wait_operation_and_get_result(
             operation,
             response_type=Function,
             meta_type=DeleteFunctionMetadata,
-        )
+            )
         return operation_result.response
 
     def set_function_access(self, function_id=None, is_public=True,
@@ -100,20 +100,20 @@ class YcFunctionsMixin:
                 subject=Subject(
                     id="allUsers",
                     type="system",
-                )
-            )]
+                    )
+                )]
         else:
             access_bindings = []
         operation = self.sdk.client(FunctionServiceStub).SetAccessBindings(
             SetAccessBindingsRequest(
                 resource_id=function_id,
                 access_bindings=access_bindings
-            ))
+                ))
         self.sdk.wait_operation_and_get_result(
             operation,
             response_type=Empty,
             meta_type=SetAccessBindingsMetadata,
-        )
+            )
         return True
 
     def _is_function_public(self, function_id) -> bool:
@@ -121,7 +121,7 @@ class YcFunctionsMixin:
             FunctionServiceStub).ListAccessBindings(
             ListAccessBindingsRequest(
                 resource_id=function_id
-            )).access_bindings
+                )).access_bindings
         for binding in access_bindings:
             if binding.role_id == 'serverless.functions.invoker':
                 subject = binding.subject
@@ -136,7 +136,8 @@ class YcFunctionsMixin:
                                 environment=None, content=None) -> Version:
         function = self.get_function(function_name)
         if content and bucket_name and object_name:
-            raise ValueError("either content of s3 bucket must be specified")
+            raise ValueError("ony one of content or s3 bucket must be "
+                             "specified")
         if content:
             operation = self.sdk.client(FunctionServiceStub).CreateVersion(
                 CreateFunctionVersionRequest(
@@ -151,8 +152,8 @@ class YcFunctionsMixin:
                     content=content,
                     named_service_accounts=named_service_accounts,
                     environment=environment
-                ))
-        else:
+                    ))
+        elif bucket_name:
             operation = self.sdk.client(FunctionServiceStub).CreateVersion(
                 CreateFunctionVersionRequest(
                     function_id=function.id,
@@ -167,12 +168,14 @@ class YcFunctionsMixin:
                                     object_name=object_name),
                     named_service_accounts=named_service_accounts,
                     environment=environment
-                ))
+                    ))
+        else:
+            raise ValueError("either bucket_name or content should be provided")
         operation_result = self.sdk.wait_operation_and_get_result(
             operation,
             response_type=Version,
             meta_type=CreateFunctionVersionMetadata,
-        )
+            )
         return operation_result.response
 
     def get_latest_version(self, function_id) -> Version:
@@ -180,5 +183,5 @@ class YcFunctionsMixin:
             GetFunctionVersionByTagRequest(
                 function_id=function_id,
                 tag="$latest",
-            ))
+                ))
         return version
